@@ -1,5 +1,5 @@
 modEvAmethods <- function(fun) {
-  # version 1.4 (11 Apr 2022)
+  # version 1.5 (10 Nov 2023)
 
   if (fun %in% c("threshMeasures", "multModEv")) {
     thresh.measures <- c("CCR", "Misclass", "Sensitivity", "Specificity", "Omission", "Commission", "Precision", "Recall", "PPP", "NPP", "UPR", "OPR", "PPI", "PAI", "kappa", "TSS", "NMI", "F1score", "OddsRatio")
@@ -16,9 +16,9 @@ modEvAmethods <- function(fun) {
 
   else if (fun == "getBins") return(c("round.prob", "prob.bins", "size.bins", "n.bins", "quantiles"))
 
-  else if (fun == "optiThresh") return(c("each", "preval", "0.5", "maxKappa", "minSensSpecDiff", "maxSensSpecSum", "maxTSS"))
+  else if (fun == "optiThresh") return(c("each", "preval", "0.5", "maxKappa", "minSensSpecDiff", "maxSensSpecSum", "maxTSS", "maxJaccard", "maxSorensen"))
 
-  else if (fun == "getThreshold") return(sort(c("preval", "trainPrev", "meanPred", "midPoint", "maxKappa", "maxCCR", "maxOPS", "maxOA", "maxF", "maxSSS", "maxTSS", "minDSS", "minDPR", "maxSPR", "minD01", "minD11", "equalPrev", "MTP")))
+  else if (fun == "getThreshold") return(sort(c("preval", "trainPrev", "meanPred", "midPoint", "maxKappa", "maxCCR", "maxOPS", "maxOA", "maxF", "maxSSS", "maxTSS", "minDSS", "minDPR", "maxSPR", "minD01", "minD11", "equalPrev", "MTP", "maxSorensen", "maxJaccard")))
 
   else stop ("Invalid 'fun' argument. Check (case-sensitive) spelling.")
 }
